"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
const commit_1 = require("./commit");
const gitgraph_1 = require("./gitgraph");
const utils_1 = require("./utils");
class Branch {
    constructor(options) {
        this.gitgraph = options.gitgraph;
        this.name = options.name;
        this.style = options.style;
        this.parentCommitHash = options.parentCommitHash;
        this.commitDefaultOptions = options.commitDefaultOptions || { style: {} };
    }
    commit(options) {
        if (typeof options === "string")
            options = { subject: options };
        if (!options)
            options = {};
        let parentOnSameBranch;
        if (!options.parents)
            options.parents = [];
        if (this.gitgraph.refs.has(this.name)) {
            parentOnSameBranch = this.gitgraph.refs.get(this.name);
            options.parents.unshift(parentOnSameBranch);
        }
        else if (this.parentCommitHash) {
            options.parents.unshift(this.parentCommitHash);
        }
        const { tag } = options, commitOptions = __rest(options, ["tag"]);
        const commit = new commit_1.default(Object.assign({ author: this.commitDefaultOptions.author || this.gitgraph.author, subject: this.commitDefaultOptions.subject ||
                this.gitgraph.commitMessage }, commitOptions, { style: this.getCommitStyle(options.style) }));
        if (parentOnSameBranch) {
            const parentRefs = (this.gitgraph.refs.get(parentOnSameBranch) ||
                []);
            parentRefs.forEach((ref) => this.gitgraph.refs.set(ref, commit.hash));
        }
        else {
            this.gitgraph.refs.set(this.name, commit.hash);
        }
        this.gitgraph.commits.push(commit);
        this.checkout();
        this.gitgraph.refs.set("HEAD", commit.hash);
        if (tag)
            this.tag(tag);
        this.gitgraph.next();
        return this;
    }
    merge(branch) {
        const branchName = typeof branch === "string" ? branch : branch.name;
        const parentCommitHash = this.gitgraph.refs.get(branchName);
        if (!parentCommitHash)
            throw new Error(`The branch called "${branchName}" is unknown`);
        this.commit({
            subject: `Merge branch ${branchName}`,
            parents: [parentCommitHash],
        });
        return this;
    }
    checkout() {
        this.gitgraph.currentBranch = this;
        return this;
    }
    tag(name) {
        this.gitgraph.tag(name, this.name);
        return this;
    }
    getCommitStyle(style = {}) {
        const message = Object.assign({}, utils_1.withoutUndefinedKeys(this.gitgraph.template.commit.message), utils_1.withoutUndefinedKeys(this.commitDefaultOptions.style.message), style.message);
        if (!this.gitgraph.isVertical || this.gitgraph.mode === gitgraph_1.ModeEnum.Compact) {
            message.display = false;
        }
        return Object.assign({}, utils_1.withoutUndefinedKeys(this.gitgraph.template.commit), utils_1.withoutUndefinedKeys(this.commitDefaultOptions.style), style, { tag: Object.assign({}, utils_1.withoutUndefinedKeys(this.gitgraph.template.commit.tag), utils_1.withoutUndefinedKeys(this.commitDefaultOptions.style.tag), style.tag), message, dot: Object.assign({}, utils_1.withoutUndefinedKeys(this.gitgraph.template.commit.dot), utils_1.withoutUndefinedKeys(this.commitDefaultOptions.style.dot), style.dot) });
    }
}
exports.Branch = Branch;
exports.default = Branch;
//# sourceMappingURL=branch.js.map