import Branch, { BranchCommitDefaultOptions } from "./branch";
import Commit from "./commit";
import { Template, TemplateEnum, CommitStyleOptions, BranchStyleOptions } from "./template";
import Refs from "./refs";
export declare enum OrientationsEnum {
    VerticalReverse = "vertical-reverse",
    Horizontal = "horizontal",
    HorizontalReverse = "horizontal-reverse"
}
export declare enum ModeEnum {
    Compact = "compact"
}
export interface Coordinate {
    x: number;
    y: number;
}
export interface GitgraphOptions {
    template?: TemplateEnum | Template;
    orientation?: OrientationsEnum;
    reverseArrow?: boolean;
    initCommitOffsetX?: number;
    initCommitOffsetY?: number;
    mode?: ModeEnum;
    author?: string;
    commitMessage?: string;
}
export interface RenderedData {
    commits: Commit[];
    branchesPaths: Map<Branch, Coordinate[][]>;
    commitMessagesX: number;
}
export interface GitgraphCommitOptions {
    author?: string;
    subject?: string;
    body?: string;
    notes?: string;
    refs?: string[];
    tree?: string;
    hash?: string;
    parents?: string[];
    style?: CommitStyleOptions;
    innerText?: string;
    tag?: string;
}
export interface GitgraphBranchOptions {
    name: string;
    commitDefaultOptions?: BranchCommitDefaultOptions;
    style?: BranchStyleOptions;
}
export declare class GitgraphCore {
    orientation?: OrientationsEnum;
    isVertical: boolean;
    reverseArrow: boolean;
    initCommitOffsetX: number;
    initCommitOffsetY: number;
    mode?: ModeEnum;
    author: string;
    commitMessage: string;
    template: Template;
    refs: Refs;
    tags: Refs;
    commits: Commit[];
    branches: Map<Branch["name"], Branch>;
    currentBranch: Branch;
    private columns;
    private rows;
    private maxRow;
    private listeners;
    constructor(options?: GitgraphOptions);
    getRenderedData(): RenderedData;
    commit(subject?: string): GitgraphCore;
    commit(options?: GitgraphCommitOptions): GitgraphCore;
    branch(options: GitgraphBranchOptions): Branch;
    branch(name: string): Branch;
    clear(): GitgraphCore;
    tag(name: string, ref?: Commit | Commit["hash"] | Branch["name"]): GitgraphCore;
    subscribe(listener: () => void): () => void;
    next(): void;
    import(data: any): this;
    private withRefsAndTags;
    private withBranches;
    private calculateRows;
    private withColor;
    private withPosition;
    private initBranchesPaths;
    private addMergeCommitsIntoBranchesPaths;
    private smoothBranchesPaths;
}
export default GitgraphCore;
