"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = require("lodash");
const utils_1 = require("./utils");
var MergeStyle;
(function (MergeStyle) {
    MergeStyle["Bezier"] = "bezier";
    MergeStyle["Straight"] = "straight";
})(MergeStyle = exports.MergeStyle || (exports.MergeStyle = {}));
class Template {
    constructor(options) {
        options.branch = options.branch || {};
        options.arrow = options.arrow || {};
        options.commit = options.commit || {};
        options.commit.dot = options.commit.dot || {};
        options.commit.tag = options.commit.tag || {};
        options.commit.message = options.commit.message || {};
        this.colors = options.colors || ["#000000"];
        this.branch = {
            color: options.branch.color,
            lineWidth: options.branch.lineWidth || 2,
            lineDash: options.branch.lineDash || [],
            showLabel: options.branch.showLabel || false,
            labelColor: options.branch.labelColor || null,
            labelFont: options.branch.labelFont || "normal 8pt Calibri",
            labelRotation: utils_1.numberOptionOr(options.branch.labelRotation, null),
            mergeStyle: options.branch.mergeStyle || MergeStyle.Bezier,
            spacing: utils_1.numberOptionOr(options.branch.spacing, 20),
        };
        this.arrow = {
            size: options.arrow.size || null,
            color: options.arrow.color || null,
            offset: options.arrow.offset || 2,
        };
        this.commit = {
            color: options.commit.color,
            spacing: utils_1.numberOptionOr(options.commit.spacing, 25),
            widthExtension: options.commit.widthExtension || 0,
            tooltipHTMLFormatter: options.commit.tooltipHTMLFormatter || null,
            shouldDisplayTooltipsInCompactMode: utils_1.booleanOptionOr(options.commit.shouldDisplayTooltipsInCompactMode, true),
            dot: {
                color: options.commit.dot.color || options.commit.color,
                size: options.commit.dot.size || 3,
                strokeWidth: utils_1.numberOptionOr(options.commit.dot.strokeWidth, 0),
                strokeColor: options.commit.dot.strokeColor,
                lineDash: options.commit.dot.lineDash || this.branch.lineDash,
            },
            tag: {
                color: options.commit.tag.color || options.commit.color,
                font: options.commit.tag.font ||
                    options.commit.message.font ||
                    "normal 10pt Calibri",
            },
            message: {
                display: utils_1.booleanOptionOr(options.commit.message.display, true),
                displayAuthor: utils_1.booleanOptionOr(options.commit.message.displayAuthor, true),
                displayBranch: utils_1.booleanOptionOr(options.commit.message.displayBranch, true),
                displayHash: utils_1.booleanOptionOr(options.commit.message.displayHash, true),
                color: options.commit.message.color || options.commit.color,
                font: options.commit.message.font || "normal 12pt Calibri",
            },
        };
    }
}
exports.Template = Template;
exports.blackArrowTemplate = new Template({
    colors: ["#6963FF", "#47E8D4", "#6BDB52", "#E84BA5", "#FFA657"],
    branch: {
        color: "#000000",
        lineWidth: 4,
        spacing: 50,
        mergeStyle: MergeStyle.Straight,
        labelRotation: 0,
    },
    commit: {
        spacing: 60,
        dot: {
            size: 16,
            strokeColor: "#000000",
            strokeWidth: 4,
        },
        message: {
            color: "black",
        },
    },
    arrow: {
        size: 16,
        offset: 2.5,
    },
});
exports.metroTemplate = new Template({
    colors: ["#979797", "#008fb5", "#f1c109"],
    branch: {
        lineWidth: 10,
        spacing: 50,
        labelRotation: 0,
    },
    commit: {
        spacing: 80,
        dot: {
            size: 14,
        },
        message: {
            font: "normal 14pt Arial",
        },
    },
});
var TemplateEnum;
(function (TemplateEnum) {
    TemplateEnum["Metro"] = "metro";
    TemplateEnum["BlackArrow"] = "blackarrow";
})(TemplateEnum = exports.TemplateEnum || (exports.TemplateEnum = {}));
function templateExtend(selectedTemplate, options) {
    return lodash_1.merge({}, getTemplate(selectedTemplate), options);
}
exports.templateExtend = templateExtend;
function getTemplate(template) {
    if (!template)
        return exports.metroTemplate;
    if (typeof template === "string") {
        return {
            [TemplateEnum.BlackArrow]: exports.blackArrowTemplate,
            [TemplateEnum.Metro]: exports.metroTemplate,
        }[template];
    }
    return template;
}
exports.getTemplate = getTemplate;
//# sourceMappingURL=template.js.map