(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('react'), require('gitgraph-core/lib/index'), require('gitgraph-core/lib/utils')) :
	typeof define === 'function' && define.amd ? define(['exports', 'react', 'gitgraph-core/lib/index', 'gitgraph-core/lib/utils'], factory) :
	(factory((global.gitgraph = global.gitgraph || {}, global.gitgraph.core = {}),global.React,global.index,global.utils));
}(this, (function (exports,React,index,utils) { 'use strict';

var __extends = (undefined && undefined.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var Gitgraph = (function (_super) {
    __extends(Gitgraph, _super);
    function Gitgraph(props) {
        var _this = _super.call(this, props) || this;
        _this.state = { commits: [], branchesPaths: new Map(), commitMessagesX: 0 };
        _this.gitgraph = new index.GitgraphCore(props.options);
        _this.gitgraph.subscribe(_this.onGitgraphCoreRender.bind(_this));
        return _this;
    }
    Gitgraph.prototype.render = function () {
        return (React.createElement("svg", { width: 1000, height: 1000 },
            this.renderBranches(),
            this.renderCommits()));
    };
    Gitgraph.prototype.componentDidMount = function () {
        this.props.children(this.gitgraph);
    };
    Gitgraph.prototype.renderBranches = function () {
        var _this = this;
        var offset = this.gitgraph.template.commit.dot.size;
        var isBezier = this.gitgraph.template.branch.mergeStyle === index.MergeStyle.Bezier;
        return Array.from(this.state.branchesPaths).map(function (_a, i) {
            var branch = _a[0], coordinates = _a[1];
            return (React.createElement("path", { key: branch.name, d: utils.toSvgPath(coordinates, isBezier, _this.gitgraph.isVertical), fill: "transparent", stroke: branch.computedColor, strokeWidth: branch.style.lineWidth, transform: "translate(" + offset + ", " + offset + ")" }));
        });
    };
    Gitgraph.prototype.renderCommits = function () {
        var _this = this;
        return this.state.commits.map(function (commit) { return (React.createElement("g", { key: commit.hashAbbrev, transform: "translate(" + commit.x + ", " + commit.y + ")" },
            React.createElement("defs", null,
                React.createElement("circle", { id: commit.hash, cx: commit.style.dot.size, cy: commit.style.dot.size, r: commit.style.dot.size, fill: commit.style.dot.color }),
                React.createElement("clipPath", { id: "clip-" + commit.hash },
                    React.createElement("use", { xlinkHref: "#" + commit.hash }))),
            React.createElement("g", null,
                React.createElement("use", { xlinkHref: "#" + commit.hash, clipPath: "url(#clip-" + commit.hash + ")", stroke: commit.style.dot.strokeColor, strokeWidth: commit.style.dot.strokeWidth && commit.style.dot.strokeWidth * 2 })),
            commit.style.message.display && (React.createElement("text", { x: _this.state.commitMessagesX - commit.x, y: commit.style.dot.size, alignmentBaseline: "central", fill: commit.style.message.color, style: { font: commit.style.message.font } }, _this.getMessage(commit))))); });
    };
    Gitgraph.prototype.getMessage = function (commit) {
        var message = "";
        if (commit.style.message.displayBranch) {
            message += "[" + commit.branches[commit.branches.length - 1];
            if (commit.tags.length) {
                message += ", " + commit.tags.join(", ");
            }
            message += "] ";
        }
        if (commit.style.message.displayHash) {
            message += commit.hashAbbrev + " ";
        }
        message += commit.subject;
        if (commit.style.message.displayAuthor) {
            message += " - " + commit.author.name + " <" + commit.author.email + ">";
        }
        return message;
    };
    Gitgraph.prototype.onGitgraphCoreRender = function () {
        var _a = this.gitgraph.getRenderedData(), commits = _a.commits, branchesPaths = _a.branchesPaths, commitMessagesX = _a.commitMessagesX;
        this.setState({ commits: commits, branchesPaths: branchesPaths, commitMessagesX: commitMessagesX });
    };
    Gitgraph.defaultProps = {
        options: {},
    };
    return Gitgraph;
}(React.Component));

exports.Gitgraph = Gitgraph;
Object.keys(index).forEach(function (key) { exports[key] = index[key]; });

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=bundle.umd.js.map
